%% ============================================================
%%   Nom de la base   :  GESTSOC                               
%%   Nom de SGBD      :  Sybase SQL Anywhere                   
%%   Date de cration :  15/12/1997  15:45                     
%% ============================================================

%  Trigger "tub_client" pour contrler avant la modification dans la table "PROJ.CLIENT"
create trigger tub_client before update of CLINUM
on PROJ.CLIENT
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Modification du code de "PROJ.CLIENT" interdite s'il existe des fils dans "PROJ.PROJET"
    if (new_upd.CLINUM <> old_upd.CLINUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  PROJ.PROJET
                      where  CLINUM = old_upd.CLINUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_client) de la table PROJ.CLIENT';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_client) de la table PROJ.CLIENT';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_client) de la table PROJ.CLIENT';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_client) de la table PROJ.CLIENT';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_client) de la table PROJ.CLIENT';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_client) avant modification de la table PROJ.CLIENT';
	resignal;
end
/

%  Trigger "tdb_client" pour contrler avant la suppression dans la table "PROJ.CLIENT"
create trigger tdb_client before delete on PROJ.CLIENT
referencing old as old_del for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare delete_parent_restrict_exception exception for SQLSTATE '99991';
    declare found integer;
    
    %  Suppression de "PROJ.CLIENT" interdite s'il existe des fils dans "PROJ.PROJET"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  PROJ.PROJET
                   where  CLINUM = old_del.CLINUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
exception
when delete_parent_restrict_exception then
	message 'Erreur: Trigger(tdb_client) de la table PROJ.CLIENT';
	message '        Il est interdit de detruire le pere s il existe un fils !';
	signal user_defined_exception;
when others then
	message 'Exception dans trigger(tdb_client) avant destruction de la table PROJ.CLIENT';
	resignal;
end
/

%  Trigger "tib_compose" pour contrler avant insertion dans la table "COMPOSE"
create trigger tib_compose before insert on COMPOSE
referencing new as new_ins for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare insert_child_parent_exist_exception exception for SQLSTATE '99991';
    declare insert_too_many_children_exception exception for SQLSTATE '99992';
    declare found integer;
    
    %  Le code de "MATERIEL" doit exister pour la cration de "COMPOSE"
    if (new_ins.MATNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  MATERIEL
                      where  MATNUM = new_ins.MATNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "MATERIEL" doit exister pour la cration de "COMPOSE"
    if (new_ins.MAT_MATNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  MATERIEL
                      where  MATNUM = new_ins.MAT_MATNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
exception
when insert_child_parent_exist_exception then
	message 'Erreur: Trigger(tib_compose) de la table COMPOSE';
	message '        Le code du pre doit exister pour l insertion du fils !';
	signal user_defined_exception;
when insert_too_many_children_exception then
   message 'Erreur: Trigger(tib_compose) de la table COMPOSE';
   message '        La cardinalit maximale a t dpasse lors de l insertion du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tib_compose) avant insertion de la table COMPOSE';
	resignal;
end
/

%  Trigger "tub_compose" pour contrler avant la modification dans la table "COMPOSE"
create trigger tub_compose before update of MATNUM,
                                            MAT_MATNUM
on COMPOSE
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Le code de "MATERIEL" doit exister pour la modification de "COMPOSE"
    if (new_upd.MATNUM is not null and
        ((old_upd.MATNUM is null) or
         (new_upd.MATNUM <> old_upd.MATNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  MATERIEL
                      where  MATNUM = new_upd.MATNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "MATERIEL" doit exister pour la modification de "COMPOSE"
    if (new_upd.MAT_MATNUM is not null and
        ((old_upd.MAT_MATNUM is null) or
         (new_upd.MAT_MATNUM <> old_upd.MAT_MATNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  MATERIEL
                      where  MATNUM = new_upd.MAT_MATNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_compose) de la table COMPOSE';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_compose) de la table COMPOSE';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_compose) de la table COMPOSE';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_compose) de la table COMPOSE';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_compose) de la table COMPOSE';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_compose) avant modification de la table COMPOSE';
	resignal;
end
/

%  Trigger "tub_division" pour contrler avant la modification dans la table "ADMN.DIVISION"
create trigger tub_division before update of DIVNUM
on ADMN.DIVISION
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Modification du code de "ADMN.DIVISION" interdite s'il existe des fils dans "SALARIE"
    if (new_upd.DIVNUM <> old_upd.DIVNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  DIVNUM = old_upd.DIVNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_division) de la table ADMN.DIVISION';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_division) de la table ADMN.DIVISION';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_division) de la table ADMN.DIVISION';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_division) de la table ADMN.DIVISION';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_division) de la table ADMN.DIVISION';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_division) avant modification de la table ADMN.DIVISION';
	resignal;
end
/

%  Trigger "tdb_division" pour contrler avant la suppression dans la table "ADMN.DIVISION"
create trigger tdb_division before delete on ADMN.DIVISION
referencing old as old_del for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare delete_parent_restrict_exception exception for SQLSTATE '99991';
    declare found integer;
    
    %  Suppression de "ADMN.DIVISION" interdite s'il existe des fils dans "SALARIE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  SALARIE
                   where  DIVNUM = old_del.DIVNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
exception
when delete_parent_restrict_exception then
	message 'Erreur: Trigger(tdb_division) de la table ADMN.DIVISION';
	message '        Il est interdit de detruire le pere s il existe un fils !';
	signal user_defined_exception;
when others then
	message 'Exception dans trigger(tdb_division) avant destruction de la table ADMN.DIVISION';
	resignal;
end
/

%  Trigger "tub_equipe" pour contrler avant la modification dans la table "EQUIPE"
create trigger tub_equipe before update of EQUNUM
on EQUIPE
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Modification du code de "EQUIPE" interdite s'il existe des fils dans "REGROUPE"
    if (new_upd.EQUNUM <> old_upd.EQUNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  REGROUPE
                      where  EQUNUM = old_upd.EQUNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_equipe) de la table EQUIPE';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_equipe) de la table EQUIPE';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_equipe) de la table EQUIPE';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_equipe) de la table EQUIPE';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_equipe) de la table EQUIPE';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_equipe) avant modification de la table EQUIPE';
	resignal;
end
/

%  Trigger "tdb_equipe" pour contrler avant la suppression dans la table "EQUIPE"
create trigger tdb_equipe before delete on EQUIPE
referencing old as old_del for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare delete_parent_restrict_exception exception for SQLSTATE '99991';
    declare found integer;
    
    %  Suppression de "EQUIPE" interdite s'il existe des fils dans "REGROUPE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  REGROUPE
                   where  EQUNUM = old_del.EQUNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
exception
when delete_parent_restrict_exception then
	message 'Erreur: Trigger(tdb_equipe) de la table EQUIPE';
	message '        Il est interdit de detruire le pere s il existe un fils !';
	signal user_defined_exception;
when others then
	message 'Exception dans trigger(tdb_equipe) avant destruction de la table EQUIPE';
	resignal;
end
/

%  Trigger "tub_materiel" pour contrler avant la modification dans la table "MATERIEL"
create trigger tub_materiel before update of MATNUM
on MATERIEL
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Modification du code de "MATERIEL" interdite s'il existe des fils dans "UTILISE"
    if (new_upd.MATNUM <> old_upd.MATNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  UTILISE
                      where  MATNUM = old_upd.MATNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
    
    %  Modification du code de "MATERIEL" interdite s'il existe des fils dans "COMPOSE"
    if (new_upd.MATNUM <> old_upd.MATNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  COMPOSE
                      where  MATNUM = old_upd.MATNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
    
    %  Modification du code de "MATERIEL" interdite s'il existe des fils dans "COMPOSE"
    if (new_upd.MATNUM <> old_upd.MATNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  COMPOSE
                      where  MAT_MATNUM = old_upd.MATNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_materiel) de la table MATERIEL';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_materiel) de la table MATERIEL';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_materiel) de la table MATERIEL';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_materiel) de la table MATERIEL';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_materiel) de la table MATERIEL';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_materiel) avant modification de la table MATERIEL';
	resignal;
end
/

%  Trigger "tdb_materiel" pour contrler avant la suppression dans la table "MATERIEL"
create trigger tdb_materiel before delete on MATERIEL
referencing old as old_del for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare delete_parent_restrict_exception exception for SQLSTATE '99991';
    declare found integer;
    
    %  Suppression de "MATERIEL" interdite s'il existe des fils dans "UTILISE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  UTILISE
                   where  MATNUM = old_del.MATNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
    
    %  Suppression de "MATERIEL" interdite s'il existe des fils dans "COMPOSE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  COMPOSE
                   where  MATNUM = old_del.MATNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
    
    %  Suppression de "MATERIEL" interdite s'il existe des fils dans "COMPOSE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  COMPOSE
                   where  MAT_MATNUM = old_del.MATNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
exception
when delete_parent_restrict_exception then
	message 'Erreur: Trigger(tdb_materiel) de la table MATERIEL';
	message '        Il est interdit de detruire le pere s il existe un fils !';
	signal user_defined_exception;
when others then
	message 'Exception dans trigger(tdb_materiel) avant destruction de la table MATERIEL';
	resignal;
end
/

%  Trigger "tib_participe" pour contrler avant insertion dans la table "PARTICIPE"
create trigger tib_participe before insert on PARTICIPE
referencing new as new_ins for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare insert_child_parent_exist_exception exception for SQLSTATE '99991';
    declare insert_too_many_children_exception exception for SQLSTATE '99992';
    declare found integer;
    
    %  Le code de "TACHE" doit exister pour la cration de "PARTICIPE"
    if (new_ins.PRONUM is not null and
        new_ins.TACNOM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  TACHE
                      where  PRONUM = new_ins.PRONUM
                       and   TACNOM = new_ins.TACNOM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "SALARIE" doit exister pour la cration de "PARTICIPE"
    if (new_ins.SALNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_ins.SALNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
exception
when insert_child_parent_exist_exception then
	message 'Erreur: Trigger(tib_participe) de la table PARTICIPE';
	message '        Le code du pre doit exister pour l insertion du fils !';
	signal user_defined_exception;
when insert_too_many_children_exception then
   message 'Erreur: Trigger(tib_participe) de la table PARTICIPE';
   message '        La cardinalit maximale a t dpasse lors de l insertion du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tib_participe) avant insertion de la table PARTICIPE';
	resignal;
end
/

%  Trigger "tub_participe" pour contrler avant la modification dans la table "PARTICIPE"
create trigger tub_participe before update of PRONUM,
                                              TACNOM,
                                              SALNUM
on PARTICIPE
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Le code de "TACHE" doit exister pour la modification de "PARTICIPE"
    if (new_upd.PRONUM is not null and
        new_upd.TACNOM is not null and
        ((old_upd.PRONUM is null and
          old_upd.TACNOM is null) or
         (new_upd.PRONUM <> old_upd.PRONUM or
          new_upd.TACNOM <> old_upd.TACNOM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  TACHE
                      where  PRONUM = new_upd.PRONUM
                       and   TACNOM = new_upd.TACNOM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "SALARIE" doit exister pour la modification de "PARTICIPE"
    if (new_upd.SALNUM is not null and
        ((old_upd.SALNUM is null) or
         (new_upd.SALNUM <> old_upd.SALNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_upd.SALNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_participe) de la table PARTICIPE';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_participe) de la table PARTICIPE';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_participe) de la table PARTICIPE';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_participe) de la table PARTICIPE';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_participe) de la table PARTICIPE';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_participe) avant modification de la table PARTICIPE';
	resignal;
end
/

%  Trigger "tib_projet" pour contrler avant insertion dans la table "PROJ.PROJET"
create trigger tib_projet before insert on PROJ.PROJET
referencing new as new_ins for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare insert_child_parent_exist_exception exception for SQLSTATE '99991';
    declare insert_too_many_children_exception exception for SQLSTATE '99992';
    declare found integer;
    
    %  Le code de "SALARIE" doit exister pour la cration de "PROJ.PROJET"
    if (new_ins.SALNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_ins.SALNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "PROJ.CLIENT" doit exister pour la cration de "PROJ.PROJET"
    if (new_ins.CLINUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  PROJ.CLIENT
                      where  CLINUM = new_ins.CLINUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
exception
when insert_child_parent_exist_exception then
	message 'Erreur: Trigger(tib_projet) de la table PROJ.PROJET';
	message '        Le code du pre doit exister pour l insertion du fils !';
	signal user_defined_exception;
when insert_too_many_children_exception then
   message 'Erreur: Trigger(tib_projet) de la table PROJ.PROJET';
   message '        La cardinalit maximale a t dpasse lors de l insertion du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tib_projet) avant insertion de la table PROJ.PROJET';
	resignal;
end
/

%  Trigger "tub_projet" pour contrler avant la modification dans la table "PROJ.PROJET"
create trigger tub_projet before update of PRONUM,
                                           SALNUM,
                                           CLINUM
on PROJ.PROJET
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Le code de "SALARIE" doit exister pour la modification de "PROJ.PROJET"
    if (new_upd.SALNUM is not null and
        ((old_upd.SALNUM is null) or
         (new_upd.SALNUM <> old_upd.SALNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_upd.SALNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "PROJ.CLIENT" doit exister pour la modification de "PROJ.PROJET"
    if (new_upd.CLINUM is not null and
        ((old_upd.CLINUM is null) or
         (new_upd.CLINUM <> old_upd.CLINUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  PROJ.CLIENT
                      where  CLINUM = new_upd.CLINUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Modification du code de "PROJ.PROJET" interdite s'il existe des fils dans "TACHE"
    if (new_upd.PRONUM <> old_upd.PRONUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  TACHE
                      where  PRONUM = old_upd.PRONUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_projet) de la table PROJ.PROJET';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_projet) de la table PROJ.PROJET';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_projet) de la table PROJ.PROJET';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_projet) de la table PROJ.PROJET';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_projet) de la table PROJ.PROJET';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_projet) avant modification de la table PROJ.PROJET';
	resignal;
end
/

%  Trigger "tdb_projet" pour contrler avant la suppression dans la table "PROJ.PROJET"
create trigger tdb_projet before delete on PROJ.PROJET
referencing old as old_del for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare delete_parent_restrict_exception exception for SQLSTATE '99991';
    declare found integer;
    
    %  Suppression de "PROJ.PROJET" interdite s'il existe des fils dans "TACHE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  TACHE
                   where  PRONUM = old_del.PRONUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
exception
when delete_parent_restrict_exception then
	message 'Erreur: Trigger(tdb_projet) de la table PROJ.PROJET';
	message '        Il est interdit de detruire le pere s il existe un fils !';
	signal user_defined_exception;
when others then
	message 'Exception dans trigger(tdb_projet) avant destruction de la table PROJ.PROJET';
	resignal;
end
/

%  Trigger "tib_regroupe" pour contrler avant insertion dans la table "REGROUPE"
create trigger tib_regroupe before insert on REGROUPE
referencing new as new_ins for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare insert_child_parent_exist_exception exception for SQLSTATE '99991';
    declare insert_too_many_children_exception exception for SQLSTATE '99992';
    declare found integer;
    
    %  Le code de "EQUIPE" doit exister pour la cration de "REGROUPE"
    if (new_ins.EQUNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  EQUIPE
                      where  EQUNUM = new_ins.EQUNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "SALARIE" doit exister pour la cration de "REGROUPE"
    if (new_ins.SALNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_ins.SALNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
exception
when insert_child_parent_exist_exception then
	message 'Erreur: Trigger(tib_regroupe) de la table REGROUPE';
	message '        Le code du pre doit exister pour l insertion du fils !';
	signal user_defined_exception;
when insert_too_many_children_exception then
   message 'Erreur: Trigger(tib_regroupe) de la table REGROUPE';
   message '        La cardinalit maximale a t dpasse lors de l insertion du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tib_regroupe) avant insertion de la table REGROUPE';
	resignal;
end
/

%  Trigger "tub_regroupe" pour contrler avant la modification dans la table "REGROUPE"
create trigger tub_regroupe before update of EQUNUM,
                                             SALNUM
on REGROUPE
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Le code de "EQUIPE" doit exister pour la modification de "REGROUPE"
    if (new_upd.EQUNUM is not null and
        ((old_upd.EQUNUM is null) or
         (new_upd.EQUNUM <> old_upd.EQUNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  EQUIPE
                      where  EQUNUM = new_upd.EQUNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "SALARIE" doit exister pour la modification de "REGROUPE"
    if (new_upd.SALNUM is not null and
        ((old_upd.SALNUM is null) or
         (new_upd.SALNUM <> old_upd.SALNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_upd.SALNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_regroupe) de la table REGROUPE';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_regroupe) de la table REGROUPE';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_regroupe) de la table REGROUPE';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_regroupe) de la table REGROUPE';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_regroupe) de la table REGROUPE';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_regroupe) avant modification de la table REGROUPE';
	resignal;
end
/

%  Trigger "tib_salarie" pour contrler avant insertion dans la table "SALARIE"
create trigger tib_salarie before insert on SALARIE
referencing new as new_ins for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare insert_child_parent_exist_exception exception for SQLSTATE '99991';
    declare insert_too_many_children_exception exception for SQLSTATE '99992';
    declare found integer;
    
    %  Le code de "ADMN.DIVISION" doit exister pour la cration de "SALARIE"
    if (new_ins.DIVNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  ADMN.DIVISION
                      where  DIVNUM = new_ins.DIVNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "SALARIE" doit exister pour la cration de "SALARIE"
    if (new_ins.SALRESP is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_ins.SALRESP);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
exception
when insert_child_parent_exist_exception then
	message 'Erreur: Trigger(tib_salarie) de la table SALARIE';
	message '        Le code du pre doit exister pour l insertion du fils !';
	signal user_defined_exception;
when insert_too_many_children_exception then
   message 'Erreur: Trigger(tib_salarie) de la table SALARIE';
   message '        La cardinalit maximale a t dpasse lors de l insertion du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tib_salarie) avant insertion de la table SALARIE';
	resignal;
end
/

%  Trigger "tub_salarie" pour contrler avant la modification dans la table "SALARIE"
create trigger tub_salarie before update of SALNUM,
                                            DIVNUM,
                                            SALRESP
on SALARIE
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Le code de "ADMN.DIVISION" doit exister pour la modification de "SALARIE"
    if (new_upd.DIVNUM is not null and
        ((old_upd.DIVNUM is null) or
         (new_upd.DIVNUM <> old_upd.DIVNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  ADMN.DIVISION
                      where  DIVNUM = new_upd.DIVNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "SALARIE" doit exister pour la modification de "SALARIE"
    if (new_upd.SALRESP is not null and
        ((old_upd.SALRESP is null) or
         (new_upd.SALRESP <> old_upd.SALRESP))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_upd.SALRESP);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Modification du code de "SALARIE" interdite s'il existe des fils dans "REGROUPE"
    if (new_upd.SALNUM <> old_upd.SALNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  REGROUPE
                      where  SALNUM = old_upd.SALNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
    
    %  Modification du code de "SALARIE" interdite s'il existe des fils dans "SALARIE"
    if (new_upd.SALNUM <> old_upd.SALNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALRESP = old_upd.SALNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
    
    %  Modification du code de "SALARIE" interdite s'il existe des fils dans "PARTICIPE"
    if (new_upd.SALNUM <> old_upd.SALNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  PARTICIPE
                      where  SALNUM = old_upd.SALNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
    
    %  Modification du code de "SALARIE" interdite s'il existe des fils dans "PROJ.PROJET"
    if (new_upd.SALNUM <> old_upd.SALNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  PROJ.PROJET
                      where  SALNUM = old_upd.SALNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
    
    %  Modification du code de "SALARIE" interdite s'il existe des fils dans "UTILISE"
    if (new_upd.SALNUM <> old_upd.SALNUM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  UTILISE
                      where  SALNUM = old_upd.SALNUM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_salarie) de la table SALARIE';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_salarie) de la table SALARIE';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_salarie) de la table SALARIE';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_salarie) de la table SALARIE';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_salarie) de la table SALARIE';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_salarie) avant modification de la table SALARIE';
	resignal;
end
/

%  Trigger "tdb_salarie" pour contrler avant la suppression dans la table "SALARIE"
create trigger tdb_salarie before delete on SALARIE
referencing old as old_del for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare delete_parent_restrict_exception exception for SQLSTATE '99991';
    declare found integer;
    
    %  Suppression de "SALARIE" interdite s'il existe des fils dans "REGROUPE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  REGROUPE
                   where  SALNUM = old_del.SALNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
    
    %  Suppression de "SALARIE" interdite s'il existe des fils dans "SALARIE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  SALARIE
                   where  SALRESP = old_del.SALNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
    
    %  Suppression de "SALARIE" interdite s'il existe des fils dans "PARTICIPE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  PARTICIPE
                   where  SALNUM = old_del.SALNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
    
    %  Suppression de "SALARIE" interdite s'il existe des fils dans "PROJ.PROJET"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  PROJ.PROJET
                   where  SALNUM = old_del.SALNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
    
    %  Suppression de "SALARIE" interdite s'il existe des fils dans "UTILISE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  UTILISE
                   where  SALNUM = old_del.SALNUM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
exception
when delete_parent_restrict_exception then
	message 'Erreur: Trigger(tdb_salarie) de la table SALARIE';
	message '        Il est interdit de detruire le pere s il existe un fils !';
	signal user_defined_exception;
when others then
	message 'Exception dans trigger(tdb_salarie) avant destruction de la table SALARIE';
	resignal;
end
/

%  Trigger "tib_tache" pour contrler avant insertion dans la table "TACHE"
create trigger tib_tache before insert on TACHE
referencing new as new_ins for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare insert_child_parent_exist_exception exception for SQLSTATE '99991';
    declare insert_too_many_children_exception exception for SQLSTATE '99992';
    declare found integer;
    
    %  Le code de "PROJ.PROJET" doit exister pour la cration de "TACHE"
    if (new_ins.PRONUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  PROJ.PROJET
                      where  PRONUM = new_ins.PRONUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
exception
when insert_child_parent_exist_exception then
	message 'Erreur: Trigger(tib_tache) de la table TACHE';
	message '        Le code du pre doit exister pour l insertion du fils !';
	signal user_defined_exception;
when insert_too_many_children_exception then
   message 'Erreur: Trigger(tib_tache) de la table TACHE';
   message '        La cardinalit maximale a t dpasse lors de l insertion du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tib_tache) avant insertion de la table TACHE';
	resignal;
end
/

%  Trigger "tub_tache" pour contrler avant la modification dans la table "TACHE"
create trigger tub_tache before update of PRONUM,
                                          TACNOM
on TACHE
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Le code de "PROJ.PROJET" doit exister pour la modification de "TACHE"
    if (new_upd.PRONUM is not null and
        ((old_upd.PRONUM is null) or
         (new_upd.PRONUM <> old_upd.PRONUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  PROJ.PROJET
                      where  PRONUM = new_upd.PRONUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Modification du code de "TACHE" interdite s'il existe des fils dans "PARTICIPE"
    if (new_upd.PRONUM <> old_upd.PRONUM or
        new_upd.TACNOM <> old_upd.TACNOM ) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  PARTICIPE
                      where  PRONUM = old_upd.PRONUM
                       and   TACNOM = old_upd.TACNOM);
       if found = 1 then
           signal update_parent_restrict_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_tache) de la table TACHE';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_tache) de la table TACHE';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_tache) de la table TACHE';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_tache) de la table TACHE';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_tache) de la table TACHE';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_tache) avant modification de la table TACHE';
	resignal;
end
/

%  Trigger "tdb_tache" pour contrler avant la suppression dans la table "TACHE"
create trigger tdb_tache before delete on TACHE
referencing old as old_del for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare delete_parent_restrict_exception exception for SQLSTATE '99991';
    declare found integer;
    
    %  Suppression de "TACHE" interdite s'il existe des fils dans "PARTICIPE"
    set found = 0;
    select 1
     into  found
     from  dummy
    where  exists (select 1
                    from  PARTICIPE
                   where  PRONUM = old_del.PRONUM
                    and   TACNOM = old_del.TACNOM);
    if found = 1 then
       signal delete_parent_restrict_exception
    end if;
exception
when delete_parent_restrict_exception then
	message 'Erreur: Trigger(tdb_tache) de la table TACHE';
	message '        Il est interdit de detruire le pere s il existe un fils !';
	signal user_defined_exception;
when others then
	message 'Exception dans trigger(tdb_tache) avant destruction de la table TACHE';
	resignal;
end
/

%  Trigger "tib_utilise" pour contrler avant insertion dans la table "UTILISE"
create trigger tib_utilise before insert on UTILISE
referencing new as new_ins for each row
begin
    declare user_defined_exception exception for SQLSTATE '99999';
    declare insert_child_parent_exist_exception exception for SQLSTATE '99991';
    declare insert_too_many_children_exception exception for SQLSTATE '99992';
    declare found integer;
    
    %  Le code de "SALARIE" doit exister pour la cration de "UTILISE"
    if (new_ins.SALNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_ins.SALNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "MATERIEL" doit exister pour la cration de "UTILISE"
    if (new_ins.MATNUM is not null) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  MATERIEL
                      where  MATNUM = new_ins.MATNUM);
       if found <> 1 then
          signal insert_child_parent_exist_exception
       end if;
    end
    end if;
exception
when insert_child_parent_exist_exception then
	message 'Erreur: Trigger(tib_utilise) de la table UTILISE';
	message '        Le code du pre doit exister pour l insertion du fils !';
	signal user_defined_exception;
when insert_too_many_children_exception then
   message 'Erreur: Trigger(tib_utilise) de la table UTILISE';
   message '        La cardinalit maximale a t dpasse lors de l insertion du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tib_utilise) avant insertion de la table UTILISE';
	resignal;
end
/

%  Trigger "tub_utilise" pour contrler avant la modification dans la table "UTILISE"
create trigger tub_utilise before update of SALNUM,
                                            MATNUM
on UTILISE
referencing new as new_upd old as old_upd for each row
begin
    declare update_change_column_exception exception for SQLSTATE '99991';
    declare update_child_change_parent_exception exception for SQLSTATE '99992';
    declare update_child_parent_exist_exception exception for SQLSTATE '99993';
    declare update_parent_restrict_exception exception for SQLSTATE '99994';
    declare update_too_many_children_exception exception for SQLSTATE '99995';
    declare found integer;
    
    %  Le code de "SALARIE" doit exister pour la modification de "UTILISE"
    if (new_upd.SALNUM is not null and
        ((old_upd.SALNUM is null) or
         (new_upd.SALNUM <> old_upd.SALNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  SALARIE
                      where  SALNUM = new_upd.SALNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
    
    %  Le code de "MATERIEL" doit exister pour la modification de "UTILISE"
    if (new_upd.MATNUM is not null and
        ((old_upd.MATNUM is null) or
         (new_upd.MATNUM <> old_upd.MATNUM))) then
    begin
       set found = 0;
       select 1
        into  found
        from  dummy
       where  exists (select 1
                       from  MATERIEL
                      where  MATNUM = new_upd.MATNUM);
       if found <> 1 then
          signal update_child_parent_exist_exception
       end if;
    end
    end if;
exception
when update_change_column_exception then
	message 'Erreur: Trigger(tub_utilise) de la table UTILISE';
	message '        Il est interdit de modifier une colonne non modifiable !';
	signal user_defined_exception;
when update_child_change_parent_exception then
	message 'Erreur: Trigger(tub_utilise) de la table UTILISE';
	message '        Il est interdit de modifier la valeur du pre dans les fils !';
	signal user_defined_exception;
when update_child_parent_exist_exception then
	message 'Erreur: Trigger(tub_utilise) de la table UTILISE';
	message '        Le code du pre doit exister pour la modification du fils !';
	signal user_defined_exception;
when update_parent_restrict_exception then
	message 'Erreur: Trigger(tub_utilise) de la table UTILISE';
	message '        Il est interdit de modifier la valeur du pre s il existe un fils !';
	signal user_defined_exception;
when update_too_many_children_exception then
   message 'Erreur: Trigger(tub_utilise) de la table UTILISE';
   message '        La cardinalit maximale a t dpasse lors de la modification du fils !';
   signal user_defined_exception;
when others then
	message 'Exception dans trigger(tub_utilise) avant modification de la table UTILISE';
	resignal;
end
/

